netapp_ontap.models.metrocluster_switchover API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.metrocluster_switchover`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class MetroclusterSwitchoverSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the MetroclusterSwitchover object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `force_on_disaster GET POST PATCH`

    The force_on_disaster field of the metrocluster_switchover.

  `mount_volumes_readonly GET POST PATCH`

    The mount_volumes_readonly field of the metrocluster_switchover.

  `simulate GET POST PATCH`

    The simulate field of the metrocluster_switchover.